#[non_exhaustive]pub struct LatestVersion {
pub repository: String,
pub latest_tag: Version,
pub pushed_at: OffsetDateTime,
pub digest: String,
}Expand description
Data model matching return type of /api/gateway/latestVersion endpoint
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository: StringThe AWS ECR repository for Freedom Gateway
latest_tag: VersionThe semantic version of the latest tag of Freedom Gateway
pushed_at: OffsetDateTimedigest: StringTrait Implementations
Sourceimpl Clone for LatestVersion
impl Clone for LatestVersion
Sourcefn clone(&self) -> LatestVersion
fn clone(&self) -> LatestVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LatestVersion
impl Debug for LatestVersion
impl Eq for LatestVersion
Sourceimpl Hash for LatestVersion
impl Hash for LatestVersion
Sourceimpl Ord for LatestVersion
impl Ord for LatestVersion
Sourcefn cmp(&self, other: &LatestVersion) -> Ordering
fn cmp(&self, other: &LatestVersion) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LatestVersion
impl PartialEq for LatestVersion
Sourcefn eq(&self, other: &LatestVersion) -> bool
fn eq(&self, other: &LatestVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for LatestVersion
impl PartialOrd for LatestVersion
impl StructuralPartialEq for LatestVersion