#[non_exhaustive]pub struct View(pub Vec<ViewOne>);Expand description
Response body for viewing all licenses associated with an account.
This is a wrapper type over a list of ViewOne items, corresponding to each license record
for the account.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: Vec<ViewOne>Trait Implementations
impl Eq for View
Sourceimpl Ord for View
impl Ord for View
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for View
impl PartialOrd for View
impl StructuralPartialEq for View