#[non_exhaustive]pub struct PayloadStatus {
pub payload_enabled: bool,
pub reason: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.payload_enabled: boolA boolean describing the availability of the Payload API
reason: Option<String>If payload_enabled == false, this field will contain a short descriptor of why